==> haskell-connection-0.2.8-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-connection.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: connection
version: 0.2.8
id: connection-0.2.8-9R9zYRKupRIFWy1APbWvSt
key: connection-0.2.8-9R9zYRKupRIFWy1APbWvSt
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-connection
synopsis: Simple and easy network connections API
description:
    Simple network library for all your connection need.
    .
    Features: Really simple to use, SSL/TLS, SOCKS.
    .
    This library provides a very simple api to create sockets
    to a destination with the choice of SSL/TLS, and SOCKS.
category: Network
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Network.Connection
hidden-modules: Network.Connection.Types
abi: 6838860db4b387e4830b13f0f20c02be
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/connection-0.2.8
library-dirs: /usr/lib/ghc-8.0.1/site-local/connection-0.2.8
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/connection-0.2.8
hs-libraries: HSconnection-0.2.8-9R9zYRKupRIFWy1APbWvSt
depends:
    base-4.9.0.0 byteable-0.1.1-15aIBCArSOBEnGxArzrDTM
    bytestring-0.10.8.1 containers-0.5.7.1
    data-default-class-0.1.2.0-6eetmQ6CbQOLoXb6k5kODu
    network-2.6.3.1-G4Up1CPKbp7DeFsnywOnGG
    socks-0.5.5-639qd4dP5FA2mjIZvcGBUX
    tls-1.3.10-FPUtFb90lmM1SPEYHO9PTG x509-1.6.5-9laM1ngk9s070ouI9TLAmW
    x509-store-1.6.2-D1ITMi7mZVrH6DgsUfztV9
    x509-system-1.6.4-9nMOWiwf8wY9F2JmnPWTY5
    x509-validation-1.6.5-hPEgdOXRQmuzHEIb9uw5
haddock-interfaces: /usr/share/doc/haskell-connection/html/connection.haddock
haddock-html: /usr/share/doc/haskell-connection/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-connection-0.2.8-9-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-connection.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: connection
version: 0.2.8
id: connection-0.2.8-EyQru0LSmMy7hVxR3M6HRH
key: connection-0.2.8-EyQru0LSmMy7hVxR3M6HRH
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-connection
synopsis: Simple and easy network connections API
description:
    Simple network library for all your connection need.
    .
    Features: Really simple to use, SSL/TLS, SOCKS.
    .
    This library provides a very simple api to create sockets
    to a destination with the choice of SSL/TLS, and SOCKS.
category: Network
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Network.Connection
hidden-modules: Network.Connection.Types
abi: 6953d3675faa3d04cd8ba83549f7156a
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/connection-0.2.8
library-dirs: /usr/lib/ghc-8.0.1/site-local/connection-0.2.8
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/connection-0.2.8
hs-libraries: HSconnection-0.2.8-EyQru0LSmMy7hVxR3M6HRH
depends:
    base-4.9.0.0 byteable-0.1.1-15aIBCArSOBEnGxArzrDTM
    bytestring-0.10.8.1 containers-0.5.7.1
    data-default-class-0.1.2.0-6eetmQ6CbQOLoXb6k5kODu
    network-2.6.3.1-G4Up1CPKbp7DeFsnywOnGG
    socks-0.5.5-639qd4dP5FA2mjIZvcGBUX
    tls-1.3.10-Blcr4Z6u3dE5lnvWI6RAH7 x509-1.6.5-DTcGavhdY587qh4PDuwE2S
    x509-store-1.6.2-BXSkkYlpuOMCVOYYZxnB5x
    x509-system-1.6.4-JcNqX3QPwSbD82Y4Lr603r
    x509-validation-1.6.5-2z5ibMGuMw95SJnBJnL5Ua
haddock-interfaces: /usr/share/doc/haskell-connection/html/connection.haddock
haddock-html: /usr/share/doc/haskell-connection/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
